pub struct DispatchInterface { /* private fields */ }Expand description
Holds the pointer to the IDispatch interface. Drop is implemented to correctly release the pointer when dropped.
Implementations
Sourceimpl DispatchInterface
impl DispatchInterface
Sourcepub fn new(dispatch: LPDISPATCH) -> DispatchInterface
pub fn new(dispatch: LPDISPATCH) -> DispatchInterface
Creates a new Dispatch Interface using the provided pointer. The pointer should not be managed by anything else after provided to the interface.
Sourcepub fn call(
&self,
name: &str,
args: Option<Vec<VariantArg>>,
) -> Result<VariantResult, Error>
pub fn call( &self, name: &str, args: Option<Vec<VariantArg>>, ) -> Result<VariantResult, Error>
This executes a dispatch method operation for the name provided and passes the arguments to the operation.
Sourcepub fn get(
&self,
name: &str,
args: Option<Vec<VariantArg>>,
) -> Result<VariantResult, Error>
pub fn get( &self, name: &str, args: Option<Vec<VariantArg>>, ) -> Result<VariantResult, Error>
This executes a property get operation for the name provided and passes the arguments to the operation.
Sourcepub fn put(
&self,
name: &str,
args: Option<Vec<VariantArg>>,
) -> Result<VariantResult, Error>
pub fn put( &self, name: &str, args: Option<Vec<VariantArg>>, ) -> Result<VariantResult, Error>
This executes a property put operation for the name provided and passes the arguments to the operation.