pub struct UnknownInterface { /* private fields */ }Expand description
UnknownInterface is a structure that maintains access to an IUnkonwn pointer. The pointer will be cleaned up correctly when the reference is dropped.
Implementations
Sourceimpl UnknownInterface
impl UnknownInterface
Sourcepub fn new(
class_id: GUID,
class_context: CLSCTX,
) -> Result<UnknownInterface, Error>
pub fn new( class_id: GUID, class_context: CLSCTX, ) -> Result<UnknownInterface, Error>
Create a new Unknown interface based on the provided class GUID and the class context.
Sourcepub fn get_dispatch_interface(&self) -> Result<DispatchInterface, Error>
pub fn get_dispatch_interface(&self) -> Result<DispatchInterface, Error>
Gets a DisptachInterface to work with the COM server registered with the class GUID provided to the unknown interface.